@@ -78,10 +78,12 @@ fi
 
 #
 [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
-echo "This command will install MBR and syslinux bootloader on this machine with $target_disk:"
+echo "This command will install MBR and syslinux bootloader on this machine"
 [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
 echo "--------------------------------------------"
+[ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
 echo "Machine: $dev_model_shown:"
+[ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
 fdisk -l $target_disk
 echo "--------------------------------------------"
 echo "Are you sure you want to continue ?"
@@ -111,10 +113,10 @@ if [ -z "$(parted -s $target_disk print | grep -E "^[[:space:]]*${pt_dev_no}\>"
   exit 1
 fi
 
-# 1. Check if partition start on cylinder boundary
-if [ -n "$(fdisk -l $target_disk | grep -i "not start on cylinder boundary")" ]; then
+# 1. Check if partition start/end on cylinder boundary
+if [ -n "$(fdisk -l $target_disk | grep -iE "(not start on cylinder boundary|not end on cylinder boundary)")" ]; then
   [ "$BOOTUP" = "color" ] && $SETCOLOR_FAILURE
-  echo "Some partition does not start on cylinder boundary! This disk is not able to boot via syslinux!" 
+  echo "Some partition does not start or end on cylinder boundary! This disk will not be able to boot via syslinux!" 
   [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
   echo "Program terminated!"
   exit 1
